@@ -7,10 +7,11 @@
 #include "legendwidget.h"
 
 #include "prefs.h"
-
 #include "kalzium_debug.h"
+
 #include <QGridLayout>
 #include <QHBoxLayout>
+#include <QStyle>
 
 #include <KLocalizedString>
 
@@ -19,6 +20,12 @@ LegendWidget::LegendWidget(QWidget *parent)
 {
     m_update = true;
     m_dockArea = Qt::BottomDockWidgetArea;
+    setContentsMargins(
+        style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+        style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+        style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+        style()->pixelMetric(QStyle::PM_LayoutBottomMargin)
+    );
 }
 
 LegendWidget::~LegendWidget()
@@ -107,12 +114,13 @@ void LegendWidget::updateLegendItemLayout(const QList<legendPair> &list)
 
     auto layout = new QGridLayout(this);
     layout->setSpacing(0);
+    layout->setVerticalSpacing(style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     layout->setContentsMargins(0, 0, 0, 0);
 
     int x = 0;
     int y = 0;
 
-    foreach (const legendPair &pair, list) {
+    for (const legendPair &pair : list) {
         auto item = new LegendItem(pair, this);
         m_legendItemList.append(item);
 
@@ -171,6 +179,7 @@ bool LegendWidget::isElementMatch(int element, QColor &color)
 }
 
 LegendItem::LegendItem(const QPair<QString, QColor> &pair, LegendWidget *parent)
+    : QLabel(parent)
 {
     auto ItemLayout = new QHBoxLayout(this);
     ItemLayout->setContentsMargins(0, 0, 0, 0);
@@ -188,8 +197,7 @@ LegendItem::LegendItem(const QPair<QString, QColor> &pair, LegendWidget *parent)
         LabelPixmap->setPixmap(LegendPixmap);
         ItemLayout->addWidget(LabelPixmap);
 
-        setFrameShape(QFrame::StyledPanel);
-        setFrameShadow(QFrame::Sunken);
+        setFrameShape(QFrame::NoFrame);
     }
     auto LegendLabel = new QLabel(this);
     LegendLabel->setText(pair.first);
